@@ -31,7 +31,11 @@ public:
 protected:
 
   //Overrides:
-  virtual void on_size_request(Gtk::Requisition* requisition);
+  virtual Gtk::SizeRequestMode get_request_mode_vfunc() const;
+  virtual void get_preferred_width_vfunc(int* minimum_width, int* natural_width) const;
+  virtual void get_preferred_height_for_width_vfunc(int width, int* minimum_height, int* natural_height) const;
+  virtual void get_preferred_height_vfunc(int* minimum_height, int* natural_height) const;
+  virtual void get_preferred_width_for_height_vfunc(int height, int* minimum_width, int* natural_width) const;
   virtual void on_size_allocate(Gtk::Allocation& allocation);
   virtual void on_map();
   virtual void on_unmap();
